#!/usr/bin/python3

RETURN = '''# '''

from subprocess import Popen, PIPE, STDOUT

def main():
    module = AnsibleModule(
        argument_spec=dict(
            mode=dict(required=False, default='check')
        ),
        supports_check_mode=False
    )
    mode = module.params['mode']

    process = Popen(['which', 'composer'], stdout=PIPE, stderr=STDOUT)
    process.wait()
    if process.stdout.read() == b'':
        module.exit_json(changed=False, result='Composer not available')

    process = Popen(['composer', 'global', 'update', '--dry-run'], stdout=PIPE, stderr=STDOUT)
    process.wait()
    updates = []
    for line in process.stdout.read().decode('utf8').split("\n"):
        line = line.strip()
        if line == '':
            # Ignore empty lines
            pass
        elif line[0] == '-':
            # This is for us
            updates.append(line)
        else:
            # Ignore everything else
            pass

    if len(updates) == 0:
        module.exit_json(changed=False, result="No updates available")

    if mode == 'upgrade':
        process = Popen(['composer', 'global', 'update', '--no-interaction'], stdout=PIPE, stderr=STDOUT)
        process.wait()
        msg = process.stdout.read().decode('utf8')
    else:
        msg = "Recommended actions:\n%s" % "\n".join(updates)

    module.exit_json(changed=True, result=msg)


from ansible.module_utils.basic import *

if __name__ == '__main__':
    main()
